@@ -25,7 +25,7 @@
  */
 
 /*
- *  Copyright (C) 2003-2012 Max-Planck-Society
+ *  Copyright (C) 2003-2014 Max-Planck-Society
  *  Author: Martin Reinecke
  */
 
@@ -35,9 +35,6 @@
 
 using namespace std;
 
-template<> const int T_Healpix_Base<int  >::order_max=13;
-template<> const int T_Healpix_Base<int64>::order_max=29;
-
 template<typename I> int T_Healpix_Base<I>::nside2order (I nside)
   {
   planck_assert (nside>I(0), "invalid value for Nside");
@@ -80,7 +77,7 @@ template<typename I, typename I2> inline void check_pixel (int o, int order_,
       int sdist=2*(order_-o); // the "bit-shift distance" between map orders
       pixset.append(pix<<sdist,(pix+1)<<sdist); // output all subpixels
       }
-    else // (zone>=1)
+    else // (1<=zone<=2)
       for (int i=0; i<4; ++i)
         stk.push_back(make_pair(4*pix+3-i,o+1)); // add children
     }
@@ -91,7 +88,7 @@ template<typename I, typename I2> inline void check_pixel (int o, int order_,
       pixset.append(pix>>(2*(o-order_))); // output the parent pixel at order_
       stk.resize(stacktop); // unwind the stack
       }
-    else // (zone>=1): pixel center in safety range
+    else // (zone==1): pixel center in safety range
       {
       if (o<omax) // check sublevels
         for (int i=0; i<4; ++i) // add children in reverse order
@@ -511,7 +508,7 @@ template<typename I> void T_Healpix_Base<I>::query_multidisc_general
   else // scheme_ == NEST
     {
     int oplus=inclusive ? 2 : 0;
-    int omax=min(order_max,order_+oplus); // the order up to which we test
+    int omax=min<int>(order_max,order_+oplus); // the order up to which we test
 
     // TODO: ignore all disks with radius>=pi
 
@@ -767,16 +764,19 @@ template<typename I> I T_Healpix_Base<I>::ring2nest (I pix) const
 template<typename I> inline I T_Healpix_Base<I>::nest_peano_helper
   (I pix, int dir) const
   {
-  int face = pix>>(2*order_);
+  int face = (pix>>(2*order_));
   I result = 0;
-  uint8 path = peano_face2path[dir][face];
-
-  for (int shift=2*order_-2; shift>=0; shift-=2)
+  int state = ((peano_face2path[dir][face]<<4))|(dir<<7);
+  int shift=2*order_-4;
+  for (; shift>=0; shift-=4)
     {
-    uint8 spix = uint8((pix>>shift) & 0x3);
-    result <<= 2;
-    result |= peano_subpix[dir][path][spix];
-    path=peano_subpath[dir][path][spix];
+    state=peano_arr2[(state&0xF0) | ((pix>>shift)&0xF)];
+    result = (result<<4) | (state&0xF);
+    }
+  if (shift==-2)
+    {
+    state=peano_arr[((state>>2)&0xFC) | (pix&0x3)];
+    result = (result<<2) | (state&0x3);
     }
 
   return result + (I(peano_face2face[dir][face])<<(2*order_));
@@ -1265,13 +1265,16 @@ template<typename I> double T_Healpix_Base<I>::max_pixrad() const
 template<typename I> double T_Healpix_Base<I>::max_pixrad(I ring) const
   {
   if (ring>=2*nside_) ring=4*nside_-ring;
-  double z=ring2z(ring), z_up=(ring>1) ? ring2z(ring-1) : 1.;
+  double z=ring2z(ring), z_up=ring2z(ring-1);
   vec3 mypos, uppos;
   uppos.set_z_phi(z_up,0);
   if (ring<=nside_)
     {
     mypos.set_z_phi(z,pi/(4*ring));
-    return v_angle(mypos,uppos);
+    double v1=v_angle(mypos,uppos);
+    if (ring!=1) return v1;
+    uppos.set_z_phi(ring2z(ring+1),pi/(4*(min(nside_,ring+1))));
+    return max(v1,v_angle(mypos,uppos));
     }
   mypos.set_z_phi(z,0);
   double vdist=v_angle(mypos,uppos);
